@@ -186,7 +186,7 @@ class M4bMerge:
         """
         # First we need to replace the terms with actual data
         # ASIN
-        self.replace_tag('asin', self.metadata.asin)
+        self.replace_tag('asin', self.metadata['asin'])
         # Author
         self.replace_tag('author', self.path_author)
         # Narrator
